@@ -1,10 +1,7 @@
 #![warn(rust_2018_idioms)]
 #![allow(dead_code)]
 
-#[macro_use]
-extern crate lazy_static;
-
 pub mod config;
 pub mod conn;
-pub mod errors;
+pub mod error;
 pub mod message;
